Changelog
=========

Version numbers comply with the `Sementic Versioning Specification (SemVer)`_.


`v0.2.0`_ (2017-08-06)
----------------------

Changed
^^^^^^^

* Guard against sending a empty draw calls.
* Prevent a breaking change planned for NumPy 1.14.
* Make the class ParticleSimulation pickable.
* Guard against processes not properly started
* Add the '.py' extension to the demo executables.
* Make minor tweaks to the code.


Fixed
^^^^^

* Fix issues specific to Windows.


v0.1.0 (2017-05-09)
-------------------

* Initial release.


.. _Sementic Versioning Specification (SemVer): http://semver.org
.. _v0.2.0: https://github.com/christophercrouzet/hienoi/compare/v0.1.0...v0.2.0
